"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyLint = void 0;
const fs_1 = require("fs");
const helpers_fn_1 = require("helpers-fn");
const lint_fn_1 = require("lint-fn");
function checkShouldContinue(result, label, debug) {
    if (debug)
        console.log(result, label);
    if (!result) {
        return true;
    }
    (0, helpers_fn_1.log)(`File is linted`, 'box');
    (0, helpers_fn_1.log)('sep');
    return false;
}
async function applyLint(input) {
    if (!(0, fs_1.existsSync)(input.fileName))
        return (0, helpers_fn_1.log)(`${input.fileName} is deleted`, 'error');
    (0, helpers_fn_1.log)('sep');
    (0, helpers_fn_1.log)(`will lint ${input.fileName}`, 'info');
    (0, helpers_fn_1.log)('sep');
    const baseProps = {
        filePath: input.fileName,
        debug: input.debug,
        useAlternativeExecCommand: input.altLintMode,
    };
    const initialLintResult = await (0, lint_fn_1.lintFn)(baseProps);
    if (!checkShouldContinue(initialLintResult, 'initial', input.debug))
        return;
    const lintResultWithOuter = await (0, lint_fn_1.lintFn)({
        ...baseProps,
        prettierSpecialCase: 'outer',
    });
    if (!checkShouldContinue(lintResultWithOuter, 'outer', input.debug))
        return;
    const lintResultWithLocal = await (0, lint_fn_1.lintFn)({
        ...baseProps,
        prettierSpecialCase: 'local',
        forceTypescript: true,
    });
    if (!checkShouldContinue(lintResultWithLocal, 'local', input.debug))
        return;
    (0, helpers_fn_1.log)(`File failed to be linted`, 'box');
}
exports.applyLint = applyLint;
