"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lintOnlyMode = exports.isLintOnlyMode = void 0;
const helpers_fn_1 = require("helpers-fn");
const lint_fn_1 = require("lint-fn");
const rambdax_1 = require("rambdax");
const pretty_html_1 = require("./pretty-html");
const sort_package_json_1 = require("./sort-package-json/sort-package-json");
const lintMethods = {
    sortPackageJson: sort_package_json_1.sortPackageJson,
    prettyHtml: pretty_html_1.prettyHtml,
    usePrettier,
};
const lintOnlyList = ['.html', '.scss', '.css', 'package.json'];
function isLintOnlyMode(filePath) {
    return (0, rambdax_1.any)((0, rambdax_1.flip)(rambdax_1.endsWith)(filePath), lintOnlyList);
}
exports.isLintOnlyMode = isLintOnlyMode;
async function usePrettier(filePath) {
    const printWidth = filePath.endsWith('.html') ? 50 : 70;
    const injectOptions = `--print-width ${printWidth}`;
    await (0, lint_fn_1.execPrettier)({
        filePath,
        injectOptions,
    });
    (0, helpers_fn_1.log)(`${filePath} linted with Prettier`, 'info');
}
async function lintOnlyMode(filePath) {
    console.log('lintOnlyMode', filePath);
    const lintMethodKey = (0, rambdax_1.switcher)(filePath)
        .is((x) => x.endsWith('package.json'), 'sortPackageJson')
        .is((x) => x.endsWith('.html'), 'prettyHtml')
        .default('usePrettier');
    const lintMethod = lintMethods[lintMethodKey];
    const lintResult = await lintMethod(filePath);
    return lintResult;
}
exports.lintOnlyMode = lintOnlyMode;
